<?php # $Id: serendipity_lang_ro.inc.php,v 1.148 2005/04/18 09:37:42 alexandruszasz Exp $
# Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
# All rights reserved.  See LICENSE file for licensing details
# Translation by Alexandru Szasz <alexxed@gmail.com>
/* vim: set sts=4 ts=4 expandtab : */

@define('LANG_CHARSET', 'UTF-8');
@define('SQL_CHARSET', 'utf8');
@define('DATE_LOCALES', 'ro_RO.UTF-8, romanian, ro, ro_RO');
@define('DATE_FORMAT_ENTRY', '%A, %B %e. %Y');
@define('DATE_FORMAT_SHORT', '%d-%m-%Y %H:%M');
@define('WYSIWYG_LANG', 'ro');
@define('NUMBER_FORMAT_DECIMALS', '2');
@define('NUMBER_FORMAT_DECPOINT', '.');
@define('NUMBER_FORMAT_THOUSANDS', ',');
@define('LANG_DIRECTION', 'ltr');

@define('SERENDIPITY_ADMIN_SUITE', 'Administrare Serendipity');
@define('HAVE_TO_BE_LOGGED_ON', 'Trebuie să fii autentificat pentru a accesa această pagină');
@define('WRONG_USERNAME_OR_PASSWORD', 'Ai introdus un utilizator sau parolă greşită');
@define('APPEARANCE', 'Aspect');
@define('MANAGE_STYLES', 'Configurare Teme');
@define('CONFIGURE_PLUGINS', 'Configurare Extensii');
@define('CONFIGURATION', 'Configurare');
@define('BACK_TO_BLOG', 'Înapoi la Weblog');
@define('LOGIN', 'Conectare');
@define('LOGOUT', 'Deconectat');
@define('LOGGEDOUT', 'Ai fost deconectat.');
@define('CREATE', 'Crează');
@define('SAVE', 'Salvează');
@define('NAME', 'Nume');
@define('CREATE_NEW_CAT', 'Crează o categorie nouă');
@define('I_WANT_THUMB', 'Vreau să folosesc miniatura în însemnarea mea.');
@define('I_WANT_BIG_IMAGE', 'Vreau să folosesc imaginea originală în însemnarea mea.');
@define('I_WANT_NO_LINK', 'Vreau să apară ca o imagine');
@define('I_WANT_IT_TO_LINK', 'Vreau să apară ca o legătură către această adresă:');
@define('BACK', 'Înapoi');
@define('FORWARD', 'Înainte');
@define('ANONYMOUS', 'Anonim');
@define('NEW_TRACKBACK_TO', 'Referinţă nouă la');
@define('NEW_COMMENT_TO', 'Comentariu nou la');
@define('RECENT', 'Recente...');
@define('OLDER', 'Mai vechi...');
@define('DONE', 'Gata');
@define('WELCOME_BACK', 'Bun venit,');
@define('TITLE', 'Titlu');
@define('DESCRIPTION', 'Descriere');
@define('PLACEMENT', 'Plasare');
@define('DELETE', 'Şterge');
@define('SAVE', 'Salvează');
@define('UP', 'SUS');
@define('DOWN', 'JOS');
@define('ENTRIES', 'însemnări');
@define('NEW_ENTRY', 'Însemnare nouă');
@define('EDIT_ENTRIES', 'Modifică însemnări');
@define('CATEGORIES', 'Categorii');
@define('WARNING_THIS_BLAHBLAH', "ATENŢIE:\\nPoate să dureze mult dacă sunt multe imagini fără miniaturi.");
@define('CREATE_THUMBS', 'Refacere Miniaturi');
@define('MANAGE_IMAGES', 'Administrare Imagini');
@define('NAME', 'Nume');
@define('EMAIL', 'Email');
@define('HOMEPAGE', 'Pagină web');
@define('COMMENT', 'Comentariu');
@define('REMEMBER_INFO', 'Păstrează informaţiile? ');
@define('SUBMIT_COMMENT', 'Adaugă Comentariu');
@define('NO_ENTRIES_TO_PRINT', 'Nici o însemnare de afişat');
@define('COMMENTS', 'Comentarii');
@define('ADD_COMMENT', 'Adaugă Comentariu');
@define('NO_COMMENTS', 'Nici un comentariu');
@define('POSTED_BY', 'Scris de');
@define('ON', 'activat');
@define('A_NEW_COMMENT_BLAHBLAH', 'A fost adăugat un nou comentariu la blog-ul tău "%s", la însemnarea cu titlul "%s".');
@define('A_NEW_TRACKBACK_BLAHBLAH', 'A fost adăugată o nouă referinţă la însemnarea din blog-ul tău cu titlul "%s".');
@define('NO_CATEGORY', 'Nici o Categorie');
@define('ENTRY_BODY', 'Textul însemnării');
@define('EXTENDED_BODY', 'Textul extins');
@define('CATEGORY', 'Categorie');
@define('EDIT', 'Modifică');
@define('NO_ENTRIES_BLAHBLAH', 'Nu am găsit nici o însemnare căutând după %s' . "\n");
@define('YOUR_SEARCH_RETURNED_BLAHBLAH', 'Căutând după %s am găsit %s rezultate:');
@define('IMAGE', 'Imagine');
@define('ERROR_FILE_NOT_EXISTS', 'Eroare: Vechiul fişier nu există!');
@define('ERROR_FILE_EXISTS', 'Eroare: Noul nume de fişier este deja folosit, alege altul!');
@define('ERROR_SOMETHING', 'Eroare: Ceva nu e în regulă.');
@define('ADDING_IMAGE', 'Adaug imagine...');
@define('THUMB_CREATED_DONE', 'Miniatură creată.<br/>Gata.');
@define('ERROR_FILE_EXISTS_ALREADY', 'Eroare: Fişierul există deja pe calculatorul tău!');
@define('ERROR_UNKNOWN_NOUPLOAD', 'Am dat peste o eroare necunoscută, nu am încărcat fişierul. Poate că mărimea fişierului este mai mare decât maximul admis de server. Ia legătură cu ISP-ul tău sau editează fişierul php.ini pentru a permite imagini mai mari.');
@define('GO', 'Du-te!');
@define('NEWSIZE', 'Noua mărime: ');
@define('RESIZE_BLAHBLAH', '<b>Redimensionează %s</b><p>');
@define('ORIGINAL_SIZE', 'Mărime originală: <i>%sx%s</i> pixel');
@define('HERE_YOU_CAN_ENTER_BLAHBLAH', '<p>Aici poţi ajusta mărimea imaginii. Dacă vrei să redimensionezi imaginea proporţional, introdu o valoare doar în una din cele 2 câmpuri şi apasă tastat TAB --  Voi calcula automat cealaltă mărime astfel încât proporţiile imaginii să nu fie alterate</p>');
@define('QUICKJUMP_CALENDAR', 'Calendar Rapid');
@define('QUICKSEARCH', 'Căutare rapidă');
@define('SEARCH_FOR_ENTRY', 'Caută după o intrare');
@define('ARCHIVES', 'Arhive');
@define('BROWSE_ARCHIVES', 'Răsfoieşte arhive după lună');
@define('TOP_REFERRER', 'Top Referinţe');
@define('SHOWS_TOP_SITES', 'Arată siturile care au legătură la blogul tău');
@define('TOP_EXITS', 'Top Ieşiri');
@define('SHOWS_TOP_EXIT', 'Arată cele mai frecvente pagini din blogul tău de pe care pleacă vizitatorii');
@define('SYNDICATION', 'Sindicat');
@define('SHOWS_RSS_BLAHBLAH', 'Arată legăturile pentru RSS');
@define('ADVERTISES_BLAHBLAH', 'Promovează originea blogului tău');
@define('HTML_NUGGET', 'Fragment HTML');
@define('HOLDS_A_BLAHBLAH', 'Menţine un fragment HTML în bara laterală');
@define('TITLE_FOR_NUGGET', 'Titlul fragmentului');
@define('THE_NUGGET', 'Fragmentul HTML!');
@define('SYNDICATE_THIS_BLOG', 'Publică acest Blog');
@define('YOU_CHOSE', 'Ai ales %s');
@define('IMAGE_ROTATE_LEFT', 'Roteşte imaginea 90 grade în sens invers acelor de ceas');
@define('IMAGE_ROTATE_RIGHT', 'Rotate imaginea 90 grade în sensul acelor de ceas');
@define('IMAGE_SIZE', 'Mărime imagine');
@define('IMAGE_AS_A_LINK', 'Inserţie imagine');
@define('POWERED_BY', 'Bazat pe');
@define('TRACKBACKS', 'Referinţe');
@define('TRACKBACK', 'Referinţă');
@define('NO_TRACKBACKS', 'Nici o referinţă');
@define('TOPICS_OF', 'Teme de');
@define('VIEW_FULL', 'văd tot');
@define('VIEW_TOPICS', 'văd teme');
@define('AT', 'la');
@define('SET_AS_TEMPLATE', 'Alege această tematică');
@define('IN', 'în');
@define('EXCERPT', 'Segment');
@define('TRACKED', 'Legat');
@define('LINK_TO_ENTRY', 'Legătură către o însemnare');
@define('LINK_TO_REMOTE_ENTRY', 'Legătură către o însemnare de pe alt blog');
@define('IP_ADDRESS', 'adresa-IP');
@define('USER', 'Utilizator');
@define('THUMBNAIL_USING_OWN', 'Folosesc %s ca miniatură pentru că este deja prea mică.');
@define('THUMBNAIL_FAILED_COPY', 'Am vrut să folosesc %s ca miniatură, dar nu am reuşit să o copiez!');
@define('AUTHOR', 'Autor');
@define('LAST_UPDATED', 'Ultima actualizare');
@define('TRACKBACK_SPECIFIC', 'URI de referinţă pentru această însemnare');
@define('DIRECT_LINK', 'Legătură directă pentru această însemnare');
@define('COMMENT_ADDED', 'Comentariul tău a fost adăugat cu succes. ');
@define('COMMENT_ADDED_CLICK', 'Click %saici pentru a te întoarce%s la comentarii, şi %saici ca să închizi%s această fereastră.');
@define('COMMENT_NOT_ADDED_CLICK', 'Click %saici pentru a te întoarce%s la comentarii, şi %saici ca să închizi%s această fereastră.');
@define('COMMENTS_DISABLE', 'Nu permite comentarii la această însemnare');
@define('COMMENTS_ENABLE', 'Permite comentarii la această însemnare');
@define('COMMENTS_CLOSED', 'Autorul nu permite comentarii la această însemnare');
@define('EMPTY_COMMENT', 'Comentariul tău nu conţine nimic, mergi %sînapoi%s şi încearcă din nou');
@define('ENTRIES_FOR', 'Însemnări pentru %s');
@define('DOCUMENT_NOT_FOUND', 'Nu am găsit documentul %s.');
@define('USERNAME', 'Utilizator');
@define('PASSWORD', 'Parola');
@define('AUTOMATIC_LOGIN', 'Salvează informaţia');
@define('SERENDIPITY_INSTALLATION', 'Instalare Serendipity');
@define('LEFT', 'stânga');
@define('RIGHT', 'dreapta');
@define('HIDDEN', 'ascuns');
@define('REMOVE_TICKED_PLUGINS', 'Elimină plugin-urile selectate');
@define('SAVE_CHANGES_TO_LAYOUT', 'Salvează schimbările legate de aspect');
@define('COMMENTS_FROM', 'Comentarii de la');
@define('ERROR', 'Eroare');
@define('ENTRY_SAVED', 'Însemnarea ta a fost salvată');
@define('DELETE_SURE', 'Eşti sigur că vrei să ştergi #%s permanent?');
@define('NOT_REALLY', 'Nu prea');
@define('DUMP_IT', 'Da, sunt sigur');
@define('RIP_ENTRY', 'Însemnarea #%s a fost ştearsă.');
@define('CATEGORY_DELETED_ARTICLES_MOVED', 'Categoria #%s a fost ştearsă. Articolele vechi au fost mutate în categoria #%s.');
@define('CATEGORY_DELETED', 'Categoria #%s a fost ştearsă.');
@define('INVALID_CATEGORY', 'Nu a fost selectată nici o categorie pentru a fi ştearsă');
@define('CATEGORY_SAVED', 'Categorie salvată');
@define('SELECT_TEMPLATE', 'Selectează tema pe care vrei să o foloseşti pentru blogul tău');
@define('ENTRIES_NOT_SUCCESSFULLY_INSERTED', 'Însemnările nu au putut fi introduse cu succes!');
@define('MT_DATA_FILE', 'Fişier cu date MT');
@define('FORCE', 'Forţează');
@define('CREATE_AUTHOR', 'Crează autor \'%s\'.');
@define('CREATE_CATEGORY', 'Crează categorie \'%s\'.');
@define('MYSQL_REQUIRED', 'Trebuie să ai extensia MySQL pentru a efectua această acţiune.');
@define('COULDNT_CONNECT', 'Nu m-am putut conecta la baza de date MySQL: %s.');
@define('COULDNT_SELECT_DB', 'Nu am putut selecta baza de date: %s.');
@define('COULDNT_SELECT_USER_INFO', 'Nu am putut colecta date despre utilizator: %s.');
@define('COULDNT_SELECT_CATEGORY_INFO', 'Nu am putut colecta date despre categorie: %s.');
@define('COULDNT_SELECT_ENTRY_INFO', 'Nu am putut colecta date despre însemnare: %s.');
@define('COULDNT_SELECT_COMMENT_INFO', 'Nu am putut colecta date despre comentariu: %s.');
@define('YES', 'Da');
@define('NO', 'Nu');
@define('USE_DEFAULT', 'Implicit');
@define('CHECK_N_SAVE', 'Verifică şi salvează');
@define('DIRECTORY_WRITE_ERROR', 'Nu pot scrie în directorul %s. Verifică te rog permisiunile.');
@define('DIRECTORY_CREATE_ERROR', 'Directorul %s nu există şi nu poate fi creat. Te rog să creezi directorul manual');
@define('DIRECTORY_RUN_CMD', '&nbsp;-&gt; execută <i>%s %s</i>');
@define('CANT_EXECUTE_BINARY', 'Nu pot executa programul %s');
@define('FILE_WRITE_ERROR', 'Nu pot scrie în fişierul %s.');
@define('FILE_CREATE_YOURSELF', 'Te rog să creezi fişierul tu sau să verifici permisiunile');
@define('COPY_CODE_BELOW', '<br />* Nu trebuie decât să copiezi codul de mai jos şi să-l pui în %s din directorul %s:<b><pre>%s</pre></b>' . "\n");
@define('WWW_USER', 'Schimbă www cu numele utilizatorului sub care rulează apache (ex. nobody).');
@define('BROWSER_RELOAD', 'După ce ai făcuta asta, reîmprospătează pagina cu butonul Reload sau Refresh.');
@define('DIAGNOSTIC_ERROR', 'Am găsit nişte erori în timp ce rulam nişte teste cu informaţiile introduse de tine:');
@define('SERENDIPITY_NOT_INSTALLED', 'Serendipity nu e instalat încă. Îl poţi <a href="%s">instala</a> acum.');
@define('INCLUDE_ERROR', 'eroare serendipity: nu am putut include %s - ies.');
@define('DATABASE_ERROR', 'eroare serendipity: nu m-am putut conecta la baza de date - ies.');
@define('CREATE_DATABASE', 'Creez baza de date implicită...');
@define('ATTEMPT_WRITE_FILE', 'Încerc să scriu fişierul %s...');
@define('WRITTEN_N_SAVED', 'Configuraţia a fost scrisă şi salvată');
@define('IMAGE_ALIGNMENT', 'Aliniere imagine');
@define('ENTER_NEW_NAME', 'Introdu numele pentru: ');
@define('RESIZING', 'Redimensionez');
@define('RESIZE_DONE', 'Gata (am redimensionat %s imagini).');
@define('SYNCING', 'Sincronizez baza de date cu directorul cu imagini');
@define('SYNC_DONE', 'Gata (am sincronizat %s imagini).');
@define('FILE_NOT_FOUND', 'Nu pot localiza fişierul denumit <b>%s</b>, poate că a fost şters deja ?');
@define('ABORT_NOW', 'Abandonează acum');
@define('REMOTE_FILE_NOT_FOUND', 'Fişierul nu a fost găsit pe serverul de la distanţă, eşti sigur că adresa: <b>%s</b> este corectă?');
@define('FILE_FETCHED', '%s luat ca %s');
@define('FILE_UPLOADED', 'Fişierul %s a fost încărcat cu succes ca %s');
@define('WORD_OR', 'Sau');
@define('SCALING_IMAGE', 'Scalare %s la %s x %s px');
@define('KEEP_PROPORTIONS', 'Păstrează proporţiile');
@define('REALLY_SCALE_IMAGE', 'Chiar vrei să redimensionezi imaginea? Operaţia este ireversibilă!');
@define('TOGGLE_ALL', 'Alternează deschide toate');
@define('TOGGLE_OPTION', 'Alternează opţiunea');
@define('SUBSCRIBE_TO_THIS_ENTRY', 'Abonează-te la această însemnare');
@define('UNSUBSCRIBE_OK', "%s nu mai este abonat la această însemnare");
@define('NEW_COMMENT_TO_SUBSCRIBED_ENTRY', 'Comentariu nou la însemnare "%s"');
@define('SUBSCRIPTION_MAIL', "Hello %s,\n\nA fost adăugat un nou comentariu la o însemnare la care tu te-ai abonat pe \"%s\", cu titlul \"%s\"\nNumele celui care a lăsat comentariul este: %s\n\nPoţi citi comentariul aici: %s\n\nPoţi renunţa la abonamentul la această însemnare cu un click aici: %s\n");
@define('SUBSCRIPTION_TRACKBACK_MAIL', "Salut %s,\n\nO nouă referinţă a fost adăugată la o însemnare la care te-ai abonat pe \"%s\", cu titlul \"%s\"\nNumele celui care a făcut referinţa este: %s\n\nPoţi găsi însemnarea aici: %s\n\nPoţi renunţa la abonamentul la această însemnare cu un click aici: %s\n");
@define('SIGNATURE', "\n-- \n%s e bazat pe Serendipity.\nCel mai bun blog din lume, îl poţi folosi şi tu.\nVizitează <http://s9y.org> ca să afli cum.");
@define('SYNDICATION_PLUGIN_091', 'Date RSS 0.91');
@define('SYNDICATION_PLUGIN_10', 'Date RSS 1.0');
@define('SYNDICATION_PLUGIN_20', 'Date RSS 2.0');
@define('SYNDICATION_PLUGIN_20c', 'Comentarii RSS 2.0');
@define('SYNDICATION_PLUGIN_ATOM03', 'Date ATOM 0.3');
@define('SYNDICATION_PLUGIN_MANAGINGEDITOR', 'Field "managingEditor"');
@define('SYNDICATION_PLUGIN_WEBMASTER',  'Field "webMaster"');
@define('SYNDICATION_PLUGIN_BANNERURL', 'Imagine pentru RSS');
@define('SYNDICATION_PLUGIN_BANNERWIDTH', 'Lăţime imagine');
@define('SYNDICATION_PLUGIN_BANNERHEIGHT', 'Înălţime imagine');
@define('SYNDICATION_PLUGIN_WEBMASTER_DESC',  'Adresa de e-mail a webmaster-ului, dacă e disponibilă. (gol=ascuns) [RSS 2.0]');
@define('SYNDICATION_PLUGIN_MANAGINGEDITOR_DESC', 'Adresa de e-mail a editorului blogului, dacă e disponibilă. (gol=ascuns) [RSS 2.0]');
@define('SYNDICATION_PLUGIN_BANNERURL_DESC', 'Adresa unei imagini în format GIF/JPEG/PNG, dacă e disponibilă. (gol=serendipity-logo)');
@define('SYNDICATION_PLUGIN_BANNERWIDTH_DESC', 'în pixeli, max. 144');
@define('SYNDICATION_PLUGIN_BANNERHEIGHT_DESC', 'în pixeli, max. 400');
@define('SYNDICATION_PLUGIN_TTL', 'Câmp "ttl" (time-to-live)');
@define('SYNDICATION_PLUGIN_TTL_DESC', 'Numărul de minute după care blog-ul tău nu va mai fi încărcat de situri/aplicaţii străine (empty: ascuns) [RSS 2.0]');
@define('SYNDICATION_PLUGIN_PUBDATE', 'Câmp "pubDate"');
@define('SYNDICATION_PLUGIN_PUBDATE_DESC', 'Includ câmpul "pubDate" la un canal RSS, pentru a arăta data ultimei însemnări?');
@define('CONTENT', 'Conţinut');
@define('TYPE', 'Tip');
@define('DRAFT', 'Ciornă');
@define('PUBLISH', 'Publică');
@define('PREVIEW', 'Previzualizare');
@define('DATE', 'Data');
@define('DATE_FORMAT_2', 'Y-m-d H:i'); // Needs to be ISO 8601 compliant for date conversion!
@define('DATE_INVALID', 'Avertisment: Data specificată de tine este invalidă. Trebuie să fie în format YYYY-MM-DD HH:MM.');
@define('CATEGORY_PLUGIN_DESC', 'Arată o listă cu categoriile.');
@define('ALL_AUTHORS', 'Toţi autorii');
@define('CATEGORIES_TO_FETCH', 'Categorii de preluat');
@define('CATEGORIES_TO_FETCH_DESC', 'De la ce autor să preiau categorii?');
@define('PAGE_BROWSE_ENTRIES', 'Pagina %s din %s, în total %s însemnări');
@define('PREVIOUS_PAGE', 'pagina precedentă');
@define('NEXT_PAGE', 'pagina următoare');
@define('ALL_CATEGORIES', 'Toate categoriile');
@define('DO_MARKUP', 'Execută transformările pentru selecţii');
@define('GENERAL_PLUGIN_DATEFORMAT', 'Format dată');
@define('GENERAL_PLUGIN_DATEFORMAT_BLAHBLAH', 'Forma datei pentru însemnare, folosind variabilele funcţiei PHP strftime(). (Implicit: "%s")');
@define('ERROR_TEMPLATE_FILE', 'Nu pot deschide fişierul cu tematică, verifică configuraţia serendipity!');
@define('ADVANCED_OPTIONS', 'Opţiuni avansate');
@define('EDIT_ENTRY', 'Modifică însemnare');
@define('HTACCESS_ERROR', 'Pentru a verifica instalarea serverului tău web, serendipity trebuie să poată scrie în fişierul ".htaccess". Acest lucru nu a fost posibil din cauza lipsei de permisiuni asupra fişierului sau directorului care îl conţine. Trebuie să schimbi permisiunile asupra fişierului astfel: <br />&nbsp;&nbsp;%s<br />şi reîncarcă această pagină.');
@define('SIDEBAR_PLUGINS', 'Extensii Bară Laterală');
@define('EVENT_PLUGINS', 'Extensii Evenimente');
@define('SORT_ORDER', 'Ordinea sortării');
@define('SORT_ORDER_NAME', 'Nume Fişier');
@define('SORT_ORDER_EXTENSION', 'Extensie Fişier');
@define('SORT_ORDER_SIZE', 'Mărime Fişier');
@define('SORT_ORDER_WIDTH', 'Lăţime Imagine');
@define('SORT_ORDER_HEIGHT', 'Înălţime Imagine');
@define('SORT_ORDER_DATE', 'Data încărcării');
@define('SORT_ORDER_ASC', 'Crescător');
@define('SORT_ORDER_DESC', 'Descrescător');
@define('THUMBNAIL_SHORT', 'Mini');
@define('ORIGINAL_SHORT', 'Orig.');
@define('APPLY_MARKUP_TO', 'Aplică selecţia pentru %s');
@define('CALENDAR_BEGINNING_OF_WEEK', 'Începutul săptămânii');
@define('SERENDIPITY_NEEDS_UPGRADE', 'Serendipity a detectat din baza de date că ai instalată versiunea %s, dar serendipity e instalat ca versiunea %s, deci trebuie să faci upgrade! <a href="%s">Click aici</a>');
@define('SERENDIPITY_UPGRADER_WELCOME', 'Salut, şi bun venit la agentul de actualizare pentru Serendipity.');
@define('SERENDIPITY_UPGRADER_PURPOSE', 'Sunt aici ca să te ajut să actualizezi instalarea ta de Serendipity %s.');
@define('SERENDIPITY_UPGRADER_WHY', 'Vezi acest mesaj pentru că tocmai ai instalat Serendipity %s, dar nu ai actualizat baza de date pentru a fi compatibilă cu această versiune');
@define('SERENDIPITY_UPGRADER_DATABASE_UPDATES', 'Actualizări baze de date (%s)');
@define('SERENDIPITY_UPGRADER_FOUND_SQL_FILES', 'Am găsit următoarele fişiere .sql care trebuie rulate pentru a folosi Serendipity');
@define('SERENDIPITY_UPGRADER_VERSION_SPECIFIC',  'Operaţii specifice versiunii');
@define('SERENDIPITY_UPGRADER_NO_VERSION_SPECIFIC', 'Nu am găsit nici o operaţie de executat specifică versiunii');
@define('SERENDIPITY_UPGRADER_PROCEED_QUESTION', 'Vrei să execuţi operaţiile de mai sus?');
@define('SERENDIPITY_UPGRADER_PROCEED_ABORT', 'Nu, le voi executa manual');
@define('SERENDIPITY_UPGRADER_PROCEED_DOIT', 'Da, chiar te rog');
@define('SERENDIPITY_UPGRADER_NO_UPGRADES', 'Se pare că nu ai nevoie de actualizări');
@define('SERENDIPITY_UPGRADER_CONSIDER_DONE', 'Consideră Serendipity actualizat');
@define('SERENDIPITY_UPGRADER_YOU_HAVE_IGNORED', 'Ai ignorat paşii de actualizare pentru Serendipity, verifică te rog dacă baza de date e corect instalată, şi eventualele operaţiile programate sunt rulate');
@define('SERENDIPITY_UPGRADER_NOW_UPGRADED', 'Instalarea Serendipity este acum actualizată la versiunea %s');
@define('SERENDIPITY_UPGRADER_RETURN_HERE', 'Te poţi întoarce la blog-ul tau cu un click %saici%s');
@define('MANAGE_USERS', 'Administrare utilizatori');
@define('CREATE_NEW_USER', 'Crează un nou utilizator');
@define('CREATE_NOT_AUTHORIZED', 'Nu poţi modifica utilizatori cu acelaşi nivel de acces ca al tău');
@define('CREATE_NOT_AUTHORIZED_USERLEVEL', 'Nu poţi creea utilizatori cu nivel de acces mai mare decât al tău');
@define('CREATED_USER', 'Am creat un nou utilizator: %s ');
@define('MODIFIED_USER', 'Am schimbat preferinţele pentru utilizatorul %s');
@define('USER_LEVEL', 'Nivel Acces');
@define('DELETE_USER', 'Eşti pe cale să ştergi utilizatorul #%d %s. Eşti sigur? Acest lucru va împiedica afişarea însemnărilor lui pe pagină.');
@define('DELETED_USER', 'Utilizatorul #%d %s a fost şters.');
@define('LIMIT_TO_NUMBER', 'Câte elemente să afişez?');
@define('ENTRIES_PER_PAGE', 'însemnări pe o pagină');
@define('XML_IMAGE_TO_DISPLAY', 'Buton XML');
@define('XML_IMAGE_TO_DISPLAY_DESC','Legăturile către serviciile de informare XML vor fi afişate sub această imagine. Lasă gol pentru valoarea implicită, sau \'none\' pentru a dezactiva această funcţionalitate.');

@define('DIRECTORIES_AVAILABLE', 'În lista subdirectoarelor disponibile poţi face click pe orice nume de director pentru a creea un nou director în acea structură.');
@define('ALL_DIRECTORIES', 'toate directoarele');
@define('MANAGE_DIRECTORIES', 'Administrează directoare');
@define('DIRECTORY_CREATED', 'Am creat directorul <strong>%s</strong>.');
@define('PARENT_DIRECTORY', 'Director părinte');
@define('CONFIRM_DELETE_DIRECTORY', 'Eşti sigur că vrei să elimini întregul conţinut al directorului %s?');
@define('ERROR_NO_DIRECTORY', 'Eroare: Directorul %s nu există');
@define('CHECKING_DIRECTORY', 'Verific fişierele din directorul %s');
@define('DELETING_FILE', 'Şterg fişierul %s...');
@define('ERROR_DIRECTORY_NOT_EMPTY', 'Nu pot şterge un director care nu este gol. Bifează "forţează ştergerea" dacă vrei să ştergi tot ceea ce conţine directorul şi trimite cererea din nou. Fişierele din director sunt:');
@define('DIRECTORY_DELETE_FAILED', 'Ştergerea directorului %s a eşuat. Verifică permisiunile sau mesajele de mai sus.');
@define('DIRECTORY_DELETE_SUCCESS', 'Directorul %s a fost şters cu succes.');
@define('SKIPPING_FILE_EXTENSION', 'Sar peste fişier: Lipseşte extensia pentru %s.');
@define('SKIPPING_FILE_UNREADABLE', 'Sar peste fişier: %s nu poate fi citit.');
@define('FOUND_FILE', 'Am găsit fişiere noi/modificate: %s.');
@define('ALREADY_SUBCATEGORY', '%s este deja o subcategorie pentru %s.');
@define('PARENT_CATEGORY', 'Categorie părinte');
@define('IN_REPLY_TO', 'Răspuns la comentariu');
@define('TOP_LEVEL', 'Însemnare');
@define('SYNDICATION_PLUGIN_GENERIC_FEED', '%s feed');
@define('PERMISSIONS', 'Permisiuni');
@define('SETTINGS_SAVED_AT', 'Noile preferinţe au fost salvate în %s');

/* DATABASE SETTINGS */
@define('INSTALL_CAT_DB', 'Preferinţe bază de date');
@define('INSTALL_CAT_DB_DESC', 'Aici poţi introduce informaţiile referitoare la baza de date. Serendipity are nevoie de aceste setări pentru a funcţiona');
@define('INSTALL_DBTYPE', 'Tipul bazei de date');
@define('INSTALL_DBTYPE_DESC', 'Tipul bazei de date');
@define('INSTALL_DBHOST', 'Adresa');
@define('INSTALL_DBHOST_DESC', 'Adresa la care se găseşte baza de date');
@define('INSTALL_DBUSER', 'Utilizator');
@define('INSTALL_DBUSER_DESC', 'Utilizatorul folosit pentru conectarea la baza de date');
@define('INSTALL_DBPASS', 'Parolă');
@define('INSTALL_DBPASS_DESC', 'Parola pentru utilizatorul de mai sus');
@define('INSTALL_DBNAME', 'Nume bază de date');
@define('INSTALL_DBNAME_DESC', 'Numele bazei tale de date');
@define('INSTALL_DBPREFIX', 'Prefixul tabelelor');
@define('INSTALL_DBPREFIX_DESC', 'Prefixul tabelelor din baza de date, ex. serendipity_');

/* PATHS */
@define('INSTALL_CAT_PATHS', 'Căi');
@define('INSTALL_CAT_PATHS_DESC', 'Diferite căi către directoare şi fişiere esenţiale. Nu uita slash-ul de la capăt pentru directoare!');
@define('INSTALL_FULLPATH', 'Cale completă');
@define('INSTALL_FULLPATH_DESC', 'Calea completă absolută către instalarea serendipity');
@define('INSTALL_UPLOADPATH', 'Cale Upload');
@define('INSTALL_UPLOADPATH_DESC', 'Toate fişierele încărcate vor fi puse aici, relativ la \'Cale completă\' - tipic: \'uploads/\'');
@define('INSTALL_RELPATH', 'Cale relativă');
@define('INSTALL_RELPATH_DESC', 'Calea către serendipity pentru web, tipic \'/serendipity/\'');
@define('INSTALL_RELTEMPLPATH', 'Cale relativă către tematici');
@define('INSTALL_RELTEMPLPATH_DESC', 'Calea către directorul care conţine tematicile tale - Relativă la \'Cale relativă\'');
@define('INSTALL_RELUPLOADPATH', 'Cale relativă upload');
@define('INSTALL_RELUPLOADPATH_DESC', 'Calea către fişierele încărcate pentru web - Relativă la \'Cale relativă\'');
@define('INSTALL_URL', 'URL către blog');
@define('INSTALL_URL_DESC', 'URL de bază către instalarea serendipity');
@define('INSTALL_INDEXFILE', 'Fişier index');
@define('INSTALL_INDEXFILE_DESC', 'Numele fişierului index pentru serendipity');

/* GENERAL SETTINGS */
@define('INSTALL_CAT_SETTINGS', 'Setări generale');
@define('INSTALL_CAT_SETTINGS_DESC', 'Personalizează modul în care funcţionează Serendipity');
@define('INSTALL_USERNAME', 'Utilizator Admin');
@define('INSTALL_USERNAME_DESC', 'Nume de utilizator pentru administrator');
@define('INSTALL_PASSWORD', 'Parolă Admin');
@define('INSTALL_PASSWORD_DESC', 'Parolă pentru administrator');
@define('INSTALL_EMAIL', 'Email Admin');
@define('INSTALL_EMAIL_DESC', 'Adresa de email pentru administratorul blog-ului');
@define('INSTALL_SENDMAIL', 'Trimit mesaje email către admin?');
@define('INSTALL_SENDMAIL_DESC', 'Vrei să primeşti mesaje pe email când sunt adăugate comentarii la însemnările tale?');
@define('INSTALL_SUBSCRIBE', 'Permiţi cititorilor să se aboneze la însemnări?');
@define('INSTALL_SUBSCRIBE_DESC', 'Permite cititorilor să se aboneze la o însemnare şi să primească un mesaj pe email când sunt adăugate noi comentarii la acea însemnare');
@define('INSTALL_BLOGNAME', 'Nume Blog');
@define('INSTALL_BLOGNAME_DESC', 'Titlu pentru blog');
@define('INSTALL_BLOGDESC', 'Desriere blog');
@define('INSTALL_BLOGDESC_DESC', 'O descriere pentru acest blog');
@define('INSTALL_LANG', 'Limbă');
@define('INSTALL_LANG_DESC', 'Alege limba pentru acest blog');

/* APPEARANCE AND OPTIONS */
@define('INSTALL_CAT_DISPLAY', 'Aspect şi opţiuni');
@define('INSTALL_CAT_DISPLAY_DESC', 'Personalizează felul în care este \'îmbrăcat\' Serendipity');
@define('INSTALL_WYSIWYG', 'Foloseşte editorul WYSIWYG (Ceea ce vezi este ceea ce obţii)');
@define('INSTALL_WYSIWYG_DESC', 'Vrei să foloseşti editorul WYSIWYG? (Merge on IE5+, Firefox şi parţial în Mozilla 1.3+)');
@define('INSTALL_XHTML11', 'Forţează compatibilitatea cu XHTML 1.1');
@define('INSTALL_XHTML11_DESC', 'Vrei să forţezi compatibilitatea cu XHTML 1.1 (poate cauza probleme pentru interfaţă/funcţionalitate în browserele mai vechi)');
@define('INSTALL_POPUP', 'Permite folosirea ferestrelor popup');
@define('INSTALL_POPUP_DESC', 'Vrei să foloseşti ferestre popup pentru comentarii, referinţe, etc ...?');
@define('INSTALL_EMBED', 'serendipity este integrat?');
@define('INSTALL_EMBED_DESC', 'Dacă vrei să incluzi serendipity într-o pagină normală, bifează aici pentru a ignora antetele şi a afişa doar conţinutul. Poţi folosi opţiunea indexFile pentru a folosi o clasă unde poţi pune antetele paginii în care e integrat serendipity. Vezi fişierul README pentru mai multe informaţii!');
@define('INSTALL_TOP_AS_LINKS', 'Arată intrările din Top Ieşiri/Referenţi ca legături?');
@define('INSTALL_TOP_AS_LINKS_DESC', '"nu": Ieşirile şi Referinţele sunt afişate doar ca text pentru a evita spam-ul de pe google. "da": Ieşirile şi Referenţii sunt afişaţi ca legături. "implicit": Foloseşte setările globale (recomandat).');
@define('INSTALL_BLOCKREF', 'Referenţi blocaţi');
@define('INSTALL_BLOCKREF_DESC', 'Există nişte adrese care nu vrei să apară în listă? Separă lista de adrese cu \';\' şi ai în vedere faptul că adresele sunt blocate după comparaţii cu subşiruri!');
@define('INSTALL_REWRITE', 'Rescriere URL');
@define('INSTALL_REWRITE_DESC', 'Alege ce reguli vrei să foloseşti când generezi un URL. Activând această opţiune va face un URL să arate mai frumos şi va fi indexat preferenţial de motoare de căutare ca google. Serverul web trebuie să aiba instalat mod_rewrite sau "AllowOverride All" pentru directorul serendipity. Opţiunea implicită este auto-detecţie');

/* IMAGECONVERSION SETTINGS */
@define('INSTALL_CAT_IMAGECONV', 'Setări Conversie Imagini');
@define('INSTALL_CAT_IMAGECONV_DESC', 'Aici sunt stocate informaţii despre cum tratează serendipity imaginile');
@define('INSTALL_IMAGEMAGICK', 'Foloseşte ImageMagick');
@define('INSTALL_IMAGEMAGICK_DESC', 'Ai ImageMagick instalat pe server şi vrei să-l foloseşti pentru redimensionarea imaginilor?');
@define('INSTALL_IMAGEMAGICKPATH', 'Calea către executabilul convert');
@define('INSTALL_IMAGEMAGICKPATH_DESC', 'Calea completă şi numele executabilului folosit de ImageMagick pentru conversia imaginilor');
@define('INSTALL_THUMBSUFFIX', 'Sufix Miniaturi');
@define('INSTALL_THUMBSUFFIX_DESC', 'Miniaturile vor fi numite după formatul: numeoriginal.[suffix].extensie');
@define('INSTALL_THUMBWIDTH', 'Dimensiuni miniaturi');
@define('INSTALL_THUMBWIDTH_DESC', 'Valori statice maxime pentru miniaturile auto-generate');

/* Personal details */
@define('USERCONF_CAT_PERSONAL', 'Detalii personale');
@define('USERCONF_CAT_PERSONAL_DESC', 'Schimbă detaliile tale personale');
@define('USERCONF_USERNAME', 'Utilizatorul tău');
@define('USERCONF_USERNAME_DESC', 'Utilizatorul cu care te autentifici în blog');
@define('USERCONF_PASSWORD', 'Parola ta');
@define('USERCONF_PASSWORD_DESC', 'Parola pe care vrei să o foloseşti pentru a te autentifica cu utilizatorul de mai sus în blog');
@define('USERCONF_EMAIL', 'Adresa e-mail');
@define('USERCONF_EMAIL_DESC', 'Adresa ta de e-mail');
@define('USERCONF_SENDCOMMENTS', 'Trimite notificări comentarii?');
@define('USERCONF_SENDCOMMENTS_DESC', 'Vrei să primeşti notificări pe email când sunt adăugate comentarii la însemnările tale?');
@define('USERCONF_SENDTRACKBACKS', 'Trimite notificări referinţe?');
@define('USERCONF_SENDTRACKBACKS_DESC', 'Vrei să primeşti notificări pe email când sunt adăugate referinţe la însemnările tale?');
@define('USERCONF_ALLOWPUBLISH', 'Drepturi: Publică însemnări?');
@define('USERCONF_ALLOWPUBLISH_DESC', 'Are dreptul acest utilizator să publice însemnări?');
@define('SUCCESS', 'Succes');
@define('POWERED_BY_SHOW_TEXT', 'Arată "Serendipity" ca text');
@define('POWERED_BY_SHOW_TEXT_DESC', 'Va afişa "Serendipity Weblog" ca text');
@define('POWERED_BY_SHOW_IMAGE', 'Arată "Serendipity" ca un logo');
@define('POWERED_BY_SHOW_IMAGE_DESC', 'Va afişa imaginea logo pentru Serendipity');
@define('PLUGIN_ITEM_DISPLAY', 'Unde ar trebui plasat acest element?');
@define('PLUGIN_ITEM_DISPLAY_EXTENDED', 'Numai însemnări avansate');
@define('PLUGIN_ITEM_DISPLAY_OVERVIEW', 'Doar pagina rezumat');
@define('PLUGIN_ITEM_DISPLAY_BOTH', 'Amândouă');
@define('RSS_IMPORT_CATEGORY', 'Foloseşte această categorie pentru însemnări importate care nu intră în nici o categorie');

@define('COMMENTS_WILL_BE_MODERATED', 'Comentariile adăugate vor fi trimise spre aprobare pentru a putea fi afişate.');
@define('YOU_HAVE_THESE_OPTIONS', 'Ai următoarele opţiuni:');
@define('THIS_COMMENT_NEEDS_REVIEW', 'Avertisment: Acest comentariu necesită aprobare pentru a putea fi afişat');
@define('DELETE_COMMENT', 'Şterge comentariu');
@define('APPROVE_COMMENT', 'Aprobă comentariu');
@define('REQUIRES_REVIEW', 'Necesită aprobare');
@define('COMMENT_APPROVED', 'Comentariul #%s a fost aprobat cu succes');
@define('COMMENT_DELETED', 'Comentariul #%s a fost şters cu succes');
@define('COMMENTS_MODERATE', 'Comentariile & referinţele la această însemnare necesită aprobare');
@define('THIS_TRACKBACK_NEEDS_REVIEW', 'Avertisment: Această referinţa necesită aprobare pentru a putea fi afişată');
@define('DELETE_TRACKBACK', 'Şterge referinţă');
@define('APPROVE_TRACKBACK', 'Aprobă referinţă');
@define('TRACKBACK_APPROVED', 'Referinţa #%s a fost aprobată cu succes');
@define('TRACKBACK_DELETED', 'Referinţa #%s a fost ştearsă cu succes');
@define('VIEW', 'Vedere');
@define('COMMENT_ALREADY_APPROVED', 'Comentariul #%s pare a fi aprobat deja');
@define('COMMENT_EDITED', 'Comentariul selectat a fost editat');
@define('HIDE', 'Ascunde');
@define('VIEW_EXTENDED_ENTRY', 'Continuă să citeşti "%s"');
@define('TRACKBACK_SPECIFIC_ON_CLICK', 'Această legătură nu e făcută pentru a fi folosită. Conţine un URI de referinţa pentru această însemnare. Poţi folosi acest URI pentru a trimite ping- & referinţe din blog-ul tău către această însemnare. Pentru a copia legătura, click dreapta pe ea şi alege "Copy Shortcut" în Internet Explorer sau "Copy Link Location" în Mozilla.');
@define('PLUGIN_SUPERUSER_HTTPS', 'Foloseşte https pentru autentificare');
@define('PLUGIN_SUPERUSER_HTTPS_DESC', 'Permite ca legătura pentru autentificare să arate către o locaţie https. Serverul tău web trebuie să suporte acest mod!');
@define('INSTALL_SHOW_EXTERNAL_LINKS', 'Permite clickul pe legăturile către exterior?');
@define('INSTALL_SHOW_EXTERNAL_LINKS_DESC', '"nu": Legăturile către exterior neverificate (Top Ieşiri, Top Referenţi, Comentarii) sunt afişate doar ca text pentru a preveni spam de google (recomandat). "da": Legăturile către exterior neverificate sunt afişate ca legături şi pot fi urmate cu un click pe ele. Această setare poate fi suprascrisă de setările extensiei Bară Laterală!');
@define('PAGE_BROWSE_COMMENTS', 'Pagina %s din %s, în total %s comentarii');
@define('FILTERS', 'Filtre');
@define('FIND_ENTRIES', 'Caută însemnări');
@define('FIND_COMMENTS', 'Caută comentarii');
@define('FIND_MEDIA', 'Caută conţinut media');
@define('FILTER_DIRECTORY', 'Director');
@define('SORT_BY', 'Sortează după');
@define('TRACKBACK_COULD_NOT_CONNECT', 'Nu am trimis referinţa: Nu am putut deschide o conexiune la %s pe portul %d');
@define('MEDIA', 'Media');
@define('MEDIA_LIBRARY', 'Librărie Media');
@define('ADD_MEDIA', 'Adaugă conţinut media');
@define('ENTER_MEDIA_URL', 'Introdu adresa unui fişier pentru a-l aduce aici:');
@define('ENTER_MEDIA_UPLOAD', 'Alege fişierul pe care vrei să-l încarci:');
@define('SAVE_FILE_AS', 'Salvează fişierul ca:');
@define('STORE_IN_DIRECTORY', 'Stochează în următorul director: ');
@define('ADD_MEDIA_BLAHBLAH', '<b>Adaugă un fişier librăriei tale multimedia:</b><p>Aici poţi încărca fişiere media de pe calculatorul tău, sau îmi poţi spune de unde să le iau de pe web! Dacă nu ai o imagine potrivită, <a href="http://images.google.com" target="_blank">caută imagini pe google</a> care corespund gândurilor tale, rezultatele sunt în majoritatea cazurilor folositoare şi amuzante :) Dar atenţie, multe imagini sunt protejate de drepturile de autor, deci ar trebui să întrebi înainte să le foloseşti.</p><p><b>Alege metoda:</b></p><br/>');
@define('MEDIA_RENAME', 'Redenumeşte acest fişier');
@define('IMAGE_RESIZE', 'Redimenzionează această imagine');
@define('MEDIA_DELETE', 'Şterge acest fişier');
@define('FILES_PER_PAGE', 'Fişiere pe o pagină');
@define('CLICK_FILE_TO_INSERT', 'Click pe fişierul pe care vrei să-l foloseşti:');
@define('SELECT_FILE', 'Alege fişierul pe care vrei să-l foloseşti');
@define('MEDIA_FULLSIZE', 'Mărime originală');
@define('CALENDAR_BOW_DESC', 'Ziua din săptămână care ar trebui considerată începutul săptămânii. Implicit e Luni');
@define('SUPERUSER', 'Administrare Blog');
@define('ALLOWS_YOU_BLAHBLAH', 'Oferă o legătură către administrarea acestui blog în Bara Laterală');
@define('CALENDAR', 'Calendar');
@define('SUPERUSER_OPEN_ADMIN', 'Deschide partea de administrare');
@define('SUPERUSER_OPEN_LOGIN', 'Deschide ecranul de autentificare');
@define('INVERT_SELECTIONS', 'Inversează selecţia');
@define('COMMENTS_DELETE_CONFIRM', 'Eşti sigur că vrei să ştergi comentariile selectate?');
@define('COMMENT_DELETE_CONFIRM', 'Eşti sigur că vrei să ştergi #%d, scris de %s?');
@define('DELETE_SELECTED_COMMENTS', 'Şterge comentariile selectate');
@define('VIEW_COMMENT', 'Vezi comentariu');
@define('VIEW_ENTRY', 'Vezi însemnare');
@define('DELETE_FILE_FAIL' , 'Nu pot şterge fişierul <b>%s</b>');
@define('DELETE_THUMBNAIL', 'Am şters miniatura cu numele <b>%s</b>');
@define('DELETE_FILE', 'Am şters fişierul cu numele <b>%s</b>');
@define('ABOUT_TO_DELETE_FILE', 'Eşti pe cale să ştergi <b>%s</b><br />Dacă foloseşti acest fişier în însemnările tale, legătura către ele nu va funcţiona iar imaginile nu vor fi afişate<br />Eşti sigur că vrei să continui?<br /><br />');
@define('TRACKBACK_SENDING', 'Trimit URI de referinţa la %s...');
@define('TRACKBACK_SENT', 'Referit cu succes');
@define('TRACKBACK_FAILED', 'Eroare referire: %s');
@define('TRACKBACK_NOT_FOUND', 'Nu am găsit URI de referinţă.');
@define('TRACKBACK_URI_MISMATCH', 'Un URI descoperit automat nu corespunde cu acest URI destinaţie.');
@define('TRACKBACK_CHECKING', 'Verific <u>%s</u> pentru referinţe posibile...');
@define('TRACKBACK_NO_DATA', 'Destinaţia nu conţine date');
@define('TRACKBACK_SIZE', 'Un URI destinaţie depăşeşte mărimea maximă de %s bytes.');
@define('COMMENTS_VIEWMODE_THREADED', 'Cascadat');
@define('COMMENTS_VIEWMODE_LINEAR', 'Liniar');
@define('DISPLAY_COMMENTS_AS', 'Arată comentariile ca');
@define('COMMENTS_FILTER_SHOW', 'Arată');
@define('COMMENTS_FILTER_ALL', 'Toate');
@define('COMMENTS_FILTER_APPROVED_ONLY', 'Doar cele aprobate');
@define('COMMENTS_FILTER_NEED_APPROVAL', 'Cele care necesită aprobare');
@define('RSS_IMPORT_BODYONLY', 'Pune tot textul importat în secţiunea "body" şi nu împărţi în "însemnare avansată".');
@define('SYNDICATION_PLUGIN_FULLFEED', 'Arată toate articolele cu corp extins din linia de informare RSS');
@define('WEEK', 'Săptămână');
@define('WEEKS', 'Săptămâni');
@define('MONTHS', 'Luni');
@define('DAYS', 'Zile');
@define('ARCHIVE_FREQUENCY', 'Frecvenţă elemente Calendar');
@define('ARCHIVE_FREQUENCY_DESC', 'Intervalul de calendar folosit între fiecare element din listă');
@define('ARCHIVE_COUNT', 'Numărul de elemente din listă');
@define('ARCHIVE_COUNT_DESC', 'Numărul total de luni, săptămâni sau zile de afişat');
@define('BELOW_IS_A_LIST_OF_INSTALLED_PLUGINS', 'Mai jos e o listă cu extensiile instalate');
@define('SIDEBAR_PLUGIN', 'extensie pentru Bară Laterală');
@define('EVENT_PLUGIN', 'Extensie Eveniment');
@define('CLICK_HERE_TO_INSTALL_PLUGIN', 'Click aici ca să instalezi o nouă %s');
@define('VERSION', 'versiune');
@define('INSTALL', 'Instalare');
@define('ALREADY_INSTALLED', 'Deja instalat');
@define('SELECT_A_PLUGIN_TO_ADD', 'Alege extensia pe care vrei să o instalezi');
@define('INSTALL_OFFSET', 'Decalaj timp server');
@define('STICKY_POSTINGS', 'Însemnări lipicioase');
@define('INSTALL_FETCHLIMIT', 'Însemnări de afişat pe prima pagină');
@define('INSTALL_FETCHLIMIT_DESC', 'Numărul de însemnări afişate pe fiecare pagină');
@define('IMPORT_ENTRIES', 'Import date');
@define('EXPORT_ENTRIES', 'Export însemnări');
@define('IMPORT_WELCOME', 'Bun venit la utilitarul pentru import Serendipity');
@define('IMPORT_WHAT_CAN', 'Aici poţi culege însemnări din alte blog-uri');
@define('IMPORT_SELECT', 'Alege software-ul folosit de blog-ul de unde vrei să culegi datele');
@define('IMPORT_PLEASE_ENTER', 'Te rog introdu datele conform cerinţelor de mai jos');
@define('IMPORT_NOW', 'Importă acum!');
@define('IMPORT_STARTING', 'Pornesc procedura de import...');
@define('IMPORT_FAILED', 'Importul a eşuat');
@define('IMPORT_DONE', 'Importul s-a terminat cu succes');
@define('IMPORT_WEBLOG_APP', 'Software Weblog');
@define('IMPORT_NOTES', 'Note:');
@define('EXPORT_FEED', 'Export linie completă RSS');
@define('STATUS', 'Stare după import');
@define('IMPORT_GENERIC_RSS', 'Import RSS generic');
@define('ACTIVATE_AUTODISCOVERY', 'Trimite Referinţe legăturilor găsite în acestă însemnare');
@define('WELCOME_TO_ADMIN', 'Bun venit în Suita de Administrare Serendipity.');
@define('PLEASE_ENTER_CREDENTIALS', 'Introdu te rog credenţialele tale mai jos.');
@define('ADMIN_FOOTER_POWERED_BY', 'Bazat pe Serendipity %s şi PHP %s');
@define('INSTALL_USEGZIP', 'Foloseşte pagini comprimate cu gzip');
@define('INSTALL_USEGZIP_DESC', 'Pentru a mări viteza de livrare a paginilor, putem comprima paginile şi să le trimitem astfel cititorului, dacă browser-ul lui suportă această funcţionalitate. Această opţiune este recomandată');
@define('INSTALL_SHOWFUTURE', 'Arată însemnările cu data în viitor');
@define('INSTALL_SHOWFUTURE_DESC', 'Dacă este activată, această opţiune va permite afişarea tuturor însemnărilor cu data în viitor în acest blog. Opţiunea implicită este să menţin însemnările cu data în viitor ascunse şi să le afişez doar când s-a ajuns la data publicării.');
@define('INSTALL_DBPERSISTENT', 'Foloseşte conexiuni persistente');
@define('INSTALL_DBPERSISTENT_DESC', 'Permite folosirea conexiunilor persistente la baza de date, citeşte mai multe <a href="http://php.net/manual/features.persistent-connections.php" target="_blank">aici</a>. Nu recomandăm această opţiune');
@define('NO_IMAGES_FOUND', 'Nu am găsit nici o imagine');
@define('PERSONAL_SETTINGS', 'Opţiuni Personale');
@define('REFERER', 'Referent');
@define('NOT_FOUND', 'Negăsit');
@define('WRITABLE', 'Se poate scrie');
@define('NOT_WRITABLE', 'Nu se poate scrie');
@define('PROBLEM_DIAGNOSTIC', 'Datorită unei probleme care a survenit, nu poţi continua instalarea până următoarele probleme nu sunt rezolvate');
@define('SELECT_INSTALLATION_TYPE', 'Alege tipul de instalare pe care îl preferi');
@define('WELCOME_TO_INSTALLATION', 'Bun venit la instalarea Serendipity');
@define('FIRST_WE_TAKE_A_LOOK', 'Pentru început, ne vom uita la instalarea curentă şi vom încerca să diagnosticăm eventualele probleme care vor apărea');
@define('ERRORS_ARE_DISPLAYED_IN', 'Erorile sunt afişate în %s, recomandările în %s iar succesul în %s');
@define('RED', 'roşu');
@define('YELLOW', 'galben');
@define('GREEN', 'verde');
@define('PRE_INSTALLATION_REPORT', 'Raport preinstalare Serendipity v%s');
@define('RECOMMENDED', 'Recomandat');
@define('ACTUAL', 'Actual');
@define('PHPINI_CONFIGURATION', 'configuraţia php.ini');
@define('PHP_INSTALLATION', 'instalarea PHP');
@define('THEY_DO', 'ei');
@define('THEY_DONT', 'ei nu');
@define('SIMPLE_INSTALLATION', 'Instalare simplă');
@define('EXPERT_INSTALLATION', 'Modul expert');
@define('COMPLETE_INSTALLATION', 'Instalare completă');
@define('WONT_INSTALL_DB_AGAIN', 'nu voi instala baza de date din nou');
@define('CHECK_DATABASE_EXISTS', 'Verific dacă baza de date şi tabelele există deja');
@define('CREATING_PRIMARY_AUTHOR', 'Creez autor principal \'%s\'');
@define('SETTING_DEFAULT_TEMPLATE', 'Aleg tematica implicită');
@define('INSTALLING_DEFAULT_PLUGINS', 'Instalez extensiile implicite');
@define('SERENDIPITY_INSTALLED', 'Serendipity a fost instalat cu succes');
@define('VISIT_BLOG_HERE', 'Vizitează noul tău blog aici');
@define('THANK_YOU_FOR_CHOOSING', 'Îţi mulţumim că ai ales Serendipity');
@define('ERROR_DETECTED_IN_INSTALL', 'A apărut o eroare în timpul instalării');
@define('OPERATING_SYSTEM', 'Sistem de operare');
@define('WEBSERVER_SAPI', 'SAPI server web');
@define('TEMPLATE_SET', '\'%s\' a fost aleasă ca tematică implicită');
@define('SEARCH_ERROR', 'Funcţia de căutare nu a funcţionat cum trebuie. Notă pentru administratorul acestui blog: Acest lucru se poate întâmpla din cauza lipsei unor chei index din baza de date. Pe sisteme cu MySQL contul cu care te conectezi la baza de date trebuie să aibă privilegii să execute: <pre>CREATE FULLTEXT INDEX entry_idx on %sentries (title,body,extended)</pre> Eroarea specifică raportată de server este: <pre>%s</pre>');
@define('EDIT_THIS_CAT', 'Editare "%s"');
@define('CATEGORY_REMAINING', 'Şterge această categorie şi mută însemnările din ea în această categorie');
@define('CATEGORY_INDEX', 'Mai jos e o listă de categorii disponibile pentr însemnările tale');
@define('NO_CATEGORIES', 'Nici o categorie');
@define('RESET_DATE', 'Reset dată');
@define('RESET_DATE_DESC', 'Click aici pentru a reseta data însemnărilor la data curentă');
@define('PROBLEM_PERMISSIONS_HOWTO', 'Permisiunile pot fi setate rulând într-un shell comanda: `<em>%s</em>` pe directorul cu probleme, sau setându-le cu ajutorul unui client FTP');
@define('WARNING_TEMPLATE_DEPRECATED', 'Avertisment: Tematica ta curentă foloseşte o metodă veche, te sfătuiesc să o actualizeze cât de curând posibil');
@define('ENTRY_PUBLISHED_FUTURE', 'Această însemnare nu este publicată încă.');
@define('ENTRIES_BY', 'Însemnări scrise de %s');
@define('PREVIOUS', 'Anterioare');
@define('NEXT', 'Următoare');
@define('APPROVE', 'Aprobă');
@define('DO_MARKUP_DESCRIPTION', 'Aplică transformări pentru text (emoticonuri, scurtături via *, /, _, ...). Dezactivând asta vei păstra eventualul cod HTML din text intact.');
@define('CATEGORY_ALREADY_EXIST', 'Există deja o categorie cu numele "%s"');
@define('ERROR_FILE_FORBIDDEN', 'Nu ai voie să încarci fişiere cu conţinut activ');
@define('ADMIN', 'Administrare');
@define('ADMIN_FRONTPAGE', 'Pagina de start');
@define('QUOTE', 'Citat');
@define('IFRAME_SAVE', 'Serendipity salvează acum însemnarea ta, creează referinţe şi posibile apeluri XML-RPC. S-ar putea să dureze...');
@define('IFRAME_SAVE_DRAFT', 'O ciornă a acestei însemnări a fost salvată');
@define('IFRAME_PREVIEW', 'Serendipity creează acum o previzualizare a însemnării...');
@define('IFRAME_WARNING', 'Browser-ul tău nu suportă conceptul de iframe. Te rog deschide fişierul serendipity_config.inc.php şi modifică $serendipity[\'use_iframe\'] în FALSE.');
@define('NONE', 'nimic');
@define('USERCONF_CAT_DEFAULT_NEW_ENTRY', 'Setări implicite pentru însemnări');
@define('UPGRADE', 'Actualizare');
@define('UPGRADE_TO_VERSION', 'Actualizare la versiunea %s');
@define('DELETE_DIRECTORY', 'Şterge director');
@define('DELETE_DIRECTORY_DESC', 'Eşti pe cale să ştergi un director care conţine fişiere media care e posibil să fie folosite în unele însemnări.');
@define('FORCE_DELETE', 'Şterge TOATE fişierele din acest director, inclusiv cele necunoscute de Serendipity');
@define('CREATE_DIRECTORY', 'Creare director');
@define('CREATE_NEW_DIRECTORY', 'Crează un nou director');
@define('CREATE_DIRECTORY_DESC', 'Aici poţi crea un nou director în care să stochezi fişierele tale media. Alege un nume pentru noul director. Opţional poţi selecta un director părinte pentru el.');
@define('BASE_DIRECTORY', 'Director de bază');
@define('USERLEVEL_EDITOR_DESC', 'Editor');
@define('USERLEVEL_CHIEF_DESC', 'Editor şef');
@define('USERLEVEL_ADMIN_DESC', 'Administrator');
@define('USERCONF_USERLEVEL', 'Nivel acces');
@define('USERCONF_USERLEVEL_DESC', 'Acest nivel este folosit pentru a determina ce fel de acces are un utilizator la acest blog');
@define('USER_SELF_INFO', 'Autentificat ca %s (%s)');
@define('ADMIN_ENTRIES', 'Însemnări');
@define('RECHECK_INSTALLATION', 'Verifică instalarea din nou');
@define('IMAGICK_EXEC_ERROR', 'Nu pot executa: "%s", eroare: %s, return var: %d');
@define('INSTALL_OFFSET_DESC', 'Introdu numărul de ore diferenţă între data serverului( acum: %clock%) şi data calculatorului de pe care scrii însemnările');
@define('UNMET_REQUIREMENTS', 'Cerinţe neîndeplinite: %s');
@define('CHARSET', 'Set caractere');
@define('AUTOLANG', 'Foloseşte ca limbă implicită cea setată de browser-ul cititorului');
@define('AUTOLANG_DESC', 'Dacă e activată, această opţiune va seta automat limba însemnării tale şi a interfeţei acestui blog conform limbii cerute de browser-ul cititorului.');
@define('INSTALL_AUTODETECT_URL', 'Autodetecţie adresă HTTP');
@define('INSTALL_AUTODETECT_URL_DESC', 'Dacă e activată, Serendipity va verifica ca adresa HTTP folosită de cititor să corespundă cu opţiunea ta BaseURL. Activând această opţiune vei putea folosi mai multe domenii pentru acest blog, şi să foloseşti domeniul pentru toate legăturile de pe acest blog.');
@define('CONVERT_HTMLENTITIES', 'Încearcă conversia automată a entităţilor HTML?');
@define('EMPTY_SETTING', 'Nu ai specificat o valoare validă pentru "%s"!');
@define('USERCONF_REALNAME', 'Nume real'); // Translate
@define('USERCONF_REALNAME_DESC', 'Numele complet al autorului. Acesta este numele vizibil cititorilor'); // Translate
@define('HOTLINK_DONE', 'Fişier legat direct.<br />Gata.'); // Translate
@define('ENTER_MEDIA_URL_METHOD', 'Metodă descărcare:'); // Translate
@define('ADD_MEDIA_BLAHBLAH_NOTE', 'Notă: Dacă alegi să faci o legătură către server, asigură-te că ai permisiunea să foloseşti conţinut de pe acel site, sau că situl e al tău. Această opţiune îţi permite să foloseşti imagini de pe alte situri fără a le stoca local.'); // Translate
@define('MEDIA_HOTLINKED', 'legat direct'); // Translate
@define('FETCH_METHOD_IMAGE', 'Descarcă imaginea pe server'); // Translate
@define('FETCH_METHOD_HOTLINK', 'Leagă direct către server'); // Translate
@define('DELETE_HOTLINK_FILE', 'Am şters fişierul legat direct cu numele <b>%s</b>'); // Translate
@define('SYNDICATION_PLUGIN_SHOW_MAIL', 'Arată adresele de email?');
@define('IMAGE_MORE_INPUT', 'Add more images'); // Translate
@define('BACKEND_TITLE', 'Additional information in Plugin Configuration screen'); // Translate
@define('BACKEND_TITLE_FOR_NUGGET', 'Here you can define a custom string which is displayed in the Plugin Configuration screen together with the description of the HTML Nugget plugin. If you have multiple HTML nuggets with an empty title, this helps to distinct the plugins from another.'); // Translate
@define('CATEGORIES_ALLOW_SELECT', 'Allow visitors to display multiple categories at once?'); // Translate
@define('CATEGORIES_ALLOW_SELECT_DESC', 'If this option is enabled, a checkbox will be put next to each category in this sidebar plugin. Users can check those boxes and then see entries belonging to their selection.'); // Translate
@define('PAGE_BROWSE_PLUGINS', 'Page %s of %s, totalling %s plugins.');
@define('INSTALL_CAT_PERMALINKS', 'Permalinks');
@define('INSTALL_CAT_PERMALINKS_DESC', 'Defines various URL patterns to define permanent links in your blog. It is suggested that you use the defaults; if not, you should try to use the %id% value where possible to prevent Serendipity from querying the database to lookup the target URL.');
@define('INSTALL_PERMALINK', 'Permalink Entry URL structure');
@define('INSTALL_PERMALINK_DESC', 'Here you can define the relative URL structure begining from your base URL to where entries may become available. You can use the variables %id%, %title%, %day%, %month%, %year% and any other characters.');
@define('INSTALL_PERMALINK_AUTHOR', 'Permalink Author URL structure');
@define('INSTALL_PERMALINK_AUTHOR_DESC', 'Here you can define the relative URL structure begining from your base URL to where entries from certain authors may become available. You can use the variables %id%, %realname%, %username%, %email% and any other characters.');
@define('INSTALL_PERMALINK_CATEGORY', 'Permalink Category URL structure');
@define('INSTALL_PERMALINK_CATEGORY_DESC', 'Here you can define the relative URL structure begining from your base URL to where entries from certain categories may become available. You can use the variables %id%, %name%, %description% and any other characters.');
@define('INSTALL_PERMALINK_FEEDCATEGORY', 'Permalink RSS-Feed Category URL structure');
@define('INSTALL_PERMALINK_FEEDCATEGORY_DESC', 'Here you can define the relative URL structure begining from your base URL to where RSS-feeds frmo certain categories may become available. You can use the variables %id%, %name%, %description% and any other characters.');
@define('INSTALL_PERMALINK_ARCHIVESPATH', 'Path to archives');
@define('INSTALL_PERMALINK_ARCHIVEPATH', 'Path to archive');
@define('INSTALL_PERMALINK_CATEGORIESPATH', 'Path to categories');
@define('INSTALL_PERMALINK_UNSUBSCRIBEPATH', 'Path to unsubscribe comments');
@define('INSTALL_PERMALINK_DELETEPATH', 'Path to delete comments');
@define('INSTALL_PERMALINK_APPROVEPATH', 'Path to approve comments');
@define('INSTALL_PERMALINK_FEEDSPATH', 'Path to RSS Feeds');
@define('INSTALL_PERMALINK_PLUGINPATH', 'Path to single plugin');
@define('INSTALL_PERMALINK_ADMINPATH', 'Path to admin');
@define('INSTALL_PERMALINK_SEARCHPATH', 'Path to search');
@define('INSTALL_CAL', 'Calendar Type');
@define('INSTALL_CAL_DESC', 'Choose your desired Calendar format');
@define('REPLY', 'Reply');
@define('USERCONF_GROUPS', 'Group Memberships');
@define('USERCONF_GROUPS_DESC', 'This user is a member of the following groups. Multiple memberships are possible.');
@define('MANAGE_GROUPS', 'Manage groups');
@define('DELETED_GROUP', 'Group #%d %s deleted.');
@define('CREATED_GROUP', 'A new group %s has been created');
@define('MODIFIED_GROUP', 'The properties of group %s have been changed');
@define('GROUP', 'Group');
@define('CREATE_NEW_GROUP', 'Create new group');
@define('DELETE_GROUP', 'You are about to delete group #%d %s. Are you serious?');
@define('USERLEVEL_OBSOLETE', 'NOTICE: The userlevel attribute is now only used for backward compatibility to plugins and fallback authorisation. User privileges are now handled by group memberships!');
@define('SYNDICATION_PLUGIN_FEEDBURNERID', 'FeedBurner ID');
@define('SYNDICATION_PLUGIN_FEEDBURNERID_DESC', 'The ID of the feed you wish to publish');
@define('SYNDICATION_PLUGIN_FEEDBURNERIMG', 'FeedBurner image');
@define('SYNDICATION_PLUGIN_FEEDBURNERIMG_DESC', 'Name of image to display (or leave blank for counter), located on feedburner.com, ex: fbapix.gif');
@define('SYNDICATION_PLUGIN_FEEDBURNERTITLE', 'FeedBurner title');
@define('SYNDICATION_PLUGIN_FEEDBURNERTITLE_DESC', 'Title (if any) to display alongside the image');
@define('SYNDICATION_PLUGIN_FEEDBURNERALT', 'FeedBurner image text');
@define('SYNDICATION_PLUGIN_FEEDBURNERALT_DESC', 'Text (if any) to display when hovering the image');
@define('SEARCH_TOO_SHORT', 'Your search-query must be longer than 3 characters. You can try to append * to shorter words, like: s9y* to trick the search into using shorter words.');
@define('INSTALL_DBPORT', 'Database port');
@define('INSTALL_DBPORT_DESC', 'The port used to connect to your database server');
@define('PLUGIN_GROUP_FRONTEND_EXTERNAL_SERVICES', 'Frontend: External Services');
@define('PLUGIN_GROUP_FRONTEND_FEATURES', 'Frontend: Features');
@define('PLUGIN_GROUP_FRONTEND_FULL_MODS', 'Frontend: Full Mods');
@define('PLUGIN_GROUP_FRONTEND_VIEWS', 'Frontend: Views');
@define('PLUGIN_GROUP_FRONTEND_ENTRY_RELATED', 'Frontend: Entry Related');
@define('PLUGIN_GROUP_BACKEND_EDITOR', 'Backend: Editor');
@define('PLUGIN_GROUP_BACKEND_USERMANAGEMENT', 'Backend: Usermanagement');
@define('PLUGIN_GROUP_BACKEND_METAINFORMATION', 'Backend: Meta information');
@define('PLUGIN_GROUP_BACKEND_TEMPLATES', 'Backend: Templates');
@define('PLUGIN_GROUP_BACKEND_FEATURES', 'Backend: Features');
@define('PLUGIN_GROUP_IMAGES', 'Images');
@define('PLUGIN_GROUP_ANTISPAM', 'Antispam');
@define('PLUGIN_GROUP_MARKUP', 'Markup');
@define('PLUGIN_GROUP_STATISTICS', 'Statistics');
@define('PERMISSION_PERSONALCONFIGURATION', 'personalConfiguration: Access personal configuration');
@define('PERMISSION_PERSONALCONFIGURATIONUSERLEVEL', 'personalConfigurationUserlevel: Change userlevels');
@define('PERMISSION_PERSONALCONFIGURATIONNOCREATE', 'personalConfigurationNoCreate: Change "forbid creating entries"');
@define('PERMISSION_PERSONALCONFIGURATIONRIGHTPUBLISH', 'personalConfigurationRightPublish: Change right to publish entries');
@define('PERMISSION_SITECONFIGURATION', 'siteConfiguration: Access system configuration');
@define('PERMISSION_BLOGCONFIGURATION', 'blogConfiguration: Access blog-centric configuration');
@define('PERMISSION_ADMINENTRIES', 'adminEntries: Administrate entries');
@define('PERMISSION_ADMINENTRIESMAINTAINOTHERS', 'adminEntriesMaintainOthers: Administrate other user\'s entries');
@define('PERMISSION_ADMINIMPORT', 'adminImport: Import entries');
@define('PERMISSION_ADMINCATEGORIES', 'adminCategories: Administrate categories');
@define('PERMISSION_ADMINCATEGORIESMAINTAINOTHERS', 'adminCategoriesMaintainOthers: Administrate other user\'s categories');
@define('PERMISSION_ADMINCATEGORIESDELETE', 'adminCategoriesDelete: Delete categories');
@define('PERMISSION_ADMINUSERS', 'adminUsers: Administrate users');
@define('PERMISSION_ADMINUSERSDELETE', 'adminUsersDelete: Delete users');
@define('PERMISSION_ADMINUSERSEDITUSERLEVEL', 'adminUsersEditUserlevel: Change userlevel');
@define('PERMISSION_ADMINUSERSMAINTAINSAME', 'adminUsersMaintainSame: Administrate users that are in your group(s)');
@define('PERMISSION_ADMINUSERSMAINTAINOTHERS', 'adminUsersMaintainOthers: Administrate users that are not in your group(s)');
@define('PERMISSION_ADMINUSERSCREATENEW', 'adminUsersCreateNew: Create new users');
@define('PERMISSION_ADMINUSERSGROUPS', 'adminUsersGroups: Administrate usergroups');
@define('PERMISSION_ADMINPLUGINS', 'adminPlugins: Administrate plugins');
@define('PERMISSION_ADMINPLUGINSMAINTAINOTHERS', 'adminPluginsMaintainOthers: Administrate other user\'s plugins');
@define('PERMISSION_ADMINIMAGES', 'adminImages: Administrate media files');
@define('PERMISSION_ADMINIMAGESDIRECTORIES', 'adminImagesDirectories: Administrate media directories');
@define('PERMISSION_ADMINIMAGESADD', 'adminImagesAdd: Add new media files');
@define('PERMISSION_ADMINIMAGESDELETE', 'adminImagesDelete: Delete media files');
@define('PERMISSION_ADMINIMAGESMAINTAINOTHERS', 'adminImagesMaintainOthers: Administrate other user\'s media files');
@define('PERMISSION_ADMINIMAGESVIEW', 'adminImagesView: View media files');
@define('PERMISSION_ADMINIMAGESSYNC', 'adminImagesSync: Sync thumbnails');
@define('PERMISSION_ADMINCOMMENTS', 'adminComments: Administrate comments');
@define('PERMISSION_ADMINTEMPLATES', 'adminTemplates: Administrate templates');
@define('INSTALL_BLOG_EMAIL', 'Blog\'s E-Mail address');
@define('INSTALL_BLOG_EMAIL_DESC', 'This configures the E-Mail address that is used as the "From"-Part of outgoing mails. Be sure to set this to an address that is recognized by the mailserver used on your host - many mailservers reject messages that have unknown From-addresses.');
@define('CATEGORIES_PARENT_BASE', 'Only show categories below...');
@define('CATEGORIES_PARENT_BASE_DESC', 'You can choose a parent category so that only the child categories are shown.');
@define('CATEGORIES_HIDE_PARALLEL', 'Hide categories that are not part of the category tree');
@define('CATEGORIES_HIDE_PARALLEL_DESC', 'If you want to hide categories that are part of a different category tree, you need to enable this. This feature makes most sense if used in conjunction with a multi-blog using the "Properties/Tempaltes of categories" plugin.');
@define('PERMISSION_ADMINIMAGESVIEWOTHERS', 'adminImagesViewOthers: View other user\'s media files');
@define('CHARSET_NATIVE', 'Native');
@define('INSTALL_CHARSET', 'Charset selection');
@define('INSTALL_CHARSET_DESC', 'Here you can toggle UTF-8 or native (ISO, EUC, ...) charactersets. Some languages only have UTF-8 translations so that setting the charset to "Native" will have no effects. UTF-8 is suggested for new installations. Do not change this setting if you have already made entries with special characters - this may lead to corrupt characters. Be sure to read more on http://www.s9y.org/index.php?node=46 about this issue.');
@define('CALENDAR_ENABLE_EXTERNAL_EVENTS', 'Enable Plugin API hook');
@define('CALENDAR_EXTEVENT_DESC', 'If enabled, plugins can hook into the calendar to display their own events highlighted. Only enable if you have installed plugins that need this, otherwise it just decreases performance.');
@define('XMLRPC_NO_LONGER_BUNDLED', 'The XML-RPC API Interface to Serendipity is no longer bundled because of ongoing security issues with this API and not many people using it. Thus you need to install the XML-RPC Plugin to use the XML-RPC API. The URL to use in your applications will NOT change - as soon as you have installed the plugin, you will again be able to use the API.');
@define('PERM_READ', 'Read permission');
@define('PERM_WRITE', 'Write permission');

@define('PERM_DENIED', 'Permission denied.');
@define('INSTALL_ACL', 'Apply read-permissions for categories');
@define('INSTALL_ACL_DESC', 'If enabled, the usergroup permission settings you setup for categories will be applied when logged-in users view your blog. If disabled, the read-permissions of the categories are NOT applied, but the positive effect is a little speedup on your blog. So if you don\'t need multi-user read permissions for your blog, disable this setting.');
@define('PLUGIN_API_VALIDATE_ERROR', 'Configuration syntax wrong for option "%s". Needs content of type "%s".');
@define('USERCONF_CHECK_PASSWORD', 'Old Password');
@define('USERCONF_CHECK_PASSWORD_DESC', 'If you change the password in the field above, you need to enter the current user password into this field.');
@define('USERCONF_CHECK_PASSWORD_ERROR', 'You did not specify the right old password, and are not authorized to change the new password. Your settings were not saved.');
@define('ERROR_XSRF', 'Your browser did not sent a valid HTTP-Referrer string. This may have either been caused by a misconfigured browser/proxy or by a Cross Site Request Forgery (XSRF) aimed at you. The action you requested could not be completed.');
@define('INSTALL_PERMALINK_FEEDAUTHOR_DESC', 'Here you can define the relative URL structure beginning from your base URL to where RSS-feeds from specific users may be viewed. You can use the variables %id%, %realname%, %username%, %email% and any other characters.');
@define('INSTALL_PERMALINK_FEEDAUTHOR', 'Permalink RSS-Feed Author URL structure');
@define('INSTALL_PERMALINK_AUTHORSPATH', 'Path to authors');
@define('AUTHORS', 'Authors');
@define('AUTHORS_ALLOW_SELECT', 'Allow visitors to display multiple authors at once?');
@define('AUTHORS_ALLOW_SELECT_DESC', 'If this option is enabled, a checkbox will be put next to each author in this sidebar plugin.  Users can check those boxes and see entries matching their selection.');
@define('AUTHOR_PLUGIN_DESC', 'Shows a list of authors');
@define('CATEGORY_PLUGIN_TEMPLATE', 'Enable Smarty-Templates?');
@define('CATEGORY_PLUGIN_TEMPLATE_DESC', 'If this option is enabled, the plugin will utilize Smarty-Templating features to output the category listing. If you enable this, you can change the layout via the "plugin_categories.tpl" template file. Enabling this option will impact performance, so if you do not need to make customizations, leave it disabled.');
@define('CATEGORY_PLUGIN_SHOWCOUNT', 'Show number of entries per category?');
@define('AUTHORS_SHOW_ARTICLE_COUNT', 'Show number of articles next to author name?');
@define('AUTHORS_SHOW_ARTICLE_COUNT_DESC', 'If this option is enabled, the number of articles by this author is shown next to the authors name in parentheses.');
@define('CUSTOM_ADMIN_INTERFACE', 'Custom admin interface available');

@define('COMMENT_NOT_ADDED', 'Comentariul tău nu a putut fi adăugat, deoarece autorul nu permite comentarii la această însemnare. '); // Retranslate: 'Your comment could not be added, because comments for this entry have either been disabled, you entered invalid data, or your comment was caught by anti-spam measurements.'
@define('INSTALL_TRACKREF', 'Enable referrer tracking?');
@define('INSTALL_TRACKREF_DESC', 'Enabling the referrer tracking will show you which sites refer to your articles. Today this is often abused for spamming, so you can disable it if you want.');
@define('CATEGORIES_HIDE_PARENT', 'Hide the selected parent category?');
@define('CATEGORIES_HIDE_PARENT_DESC', 'If you restrict the listing of categories to a specific category, by default you will see that parent category within the output listing. If you disable this option, the parent category name will not be displayed.');
@define('WARNING_NO_GROUPS_SELECTED', 'Warning: You did not select any group memberships. This would effectively log you out of the usergroup management, and thus your group memberships werde not changed.');
@define('INSTALL_RSSFETCHLIMIT', 'Entries to display in Feeds');
@define('INSTALL_RSSFETCHLIMIT_DESC', 'Number of entries to display for each page on the RSS Feed.');
@define('INSTAL_DB_UTF8', 'Enable DB-charset conversion');
@define('INSTAL_DB_UTF8_DESC', 'Issues a MySQL "SET NAMES" query to indicate the required charset for the database. Turn this on or off, if you see weird characters in your blog.');
@define('ONTHEFLYSYNCH', 'Enable on-the-fly media synchronization');
@define('ONTHEFLYSYNCH_DESC', 'If enabled, Serendipity will compare the media database with the files stored on your server and synchronize the database and directory contents.');
@define('USERCONF_CHECK_USERNAME_ERROR', 'The username cannot be left blank.');
@define('FURTHER_LINKS', 'Further Links');
@define('FURTHER_LINKS_S9Y', 'Serendipity Homepage');
@define('FURTHER_LINKS_S9Y_DOCS', 'Serendipity Documentation');
@define('FURTHER_LINKS_S9Y_BLOG', 'Official Blog');
@define('FURTHER_LINKS_S9Y_FORUMS', 'Forums');
@define('FURTHER_LINKS_S9Y_SPARTACUS', 'Spartacus');
@define('COMMENT_IS_DELETED', '(Comment removed)');

@define('CURRENT_AUTHOR', 'Current author');

@define('WORD_NEW', 'New');
@define('SHOW_MEDIA_TOOLBAR', 'Show toolbar within media selector popup?');
@define('MEDIA_KEYWORDS', 'Media keywords');
@define('MEDIA_KEYWORDS_DESC', 'Enter a list of ";" separated words that you want to use as pre-defined keywords for media items.');
@define('MEDIA_EXIF', 'Import EXIF/JPEG image data');
@define('MEDIA_EXIF_DESC', 'If enabled, existing EXIF/JPEG metadata of images will be parsed and stored in the database for display in the media gallery.');
@define('MEDIA_PROP', 'Media properties');


@define('GO_ADD_PROPERTIES', 'Go & enter properties');
@define('MEDIA_PROPERTY_DPI', 'DPI');
@define('MEDIA_PROPERTY_COPYRIGHT', 'Copyright');
@define('MEDIA_PROPERTY_COMMENT1', 'Short Comment');
@define('MEDIA_PROPERTY_COMMENT2', 'Long Comment');
@define('MEDIA_PROPERTY_TITLE', 'Title');
@define('MEDIA_PROP_DESC', 'Enter a list of ";" separated property fields you want to define for each media file');
@define('MEDIA_PROP_MULTIDESC', '(You can append ":MULTI" after any item to indicate that this item will contain long text instead of just some characters)');

@define('STYLE_OPTIONS_NONE', 'This theme/style has no specific options. To see how your template can specify options, read the Technical Documentation on www.s9y.org about "Configuration of Theme options".');
@define('STYLE_OPTIONS', 'Theme/Style options');

@define('PLUGIN_AVAILABLE_COUNT', 'Total: %d plugins.');

@define('SYNDICATION_RFC2616', 'Activate strict RFC2616 RSS-Feed compliance');
@define('SYNDICATION_RFC2616_DESC', 'NOT Enforcing RFC2616 means that all Conditional GETs to Serendipity will return entries last modified since the time of the last request. With that setting to "false", your visitors will get all articles since their last request, which is considered a good thing. However, some Agents like Planet act weird, if that happens, at it also violates RFC2616. So if you set this option to "TRUE" you will comply with that RFC, but readers of your RSS feed might miss items in their holidays. So either way, either it hearts Aggregators like Planet, or it hurts actual readers of your blog. If you are facing complaints from either side, you can toggle this option. Reference: <a href="https://sourceforge.net/tracker/index.php?func=detail&amp;aid=1461728&amp;group_id=75065&amp;atid=542822" target="_blank" rel="nofollow">SourceForge</a>');
@define('MEDIA_PROPERTY_DATE', 'Associated Date');
@define('MEDIA_PROPERTY_RUN_LENGTH', 'Run-Length');
@define('FILENAME_REASSIGNED', 'Automagically assigned new file name: %s');
@define('MEDIA_UPLOAD_SIZE', 'Max. file upload size');
@define('MEDIA_UPLOAD_SIZE_DESC', 'Enter the maximum filesize for uploaded files in bytes. This setting can be overruled by server-side settings in PHP.ini: upload_max_filesize, post_max_size, max_input_time all take precedence over this option. An empty string means to only use the server-side limits.');
@define('MEDIA_UPLOAD_SIZEERROR', 'Error: You cannot upload files larger than %s bytes!');
@define('MEDIA_UPLOAD_MAXWIDTH', 'Max. width of image files for upload');
@define('MEDIA_UPLOAD_MAXWIDTH_DESC', 'Enter the maximum image width in pixels for uploaded images.');
@define('MEDIA_UPLOAD_MAXHEIGHT', 'Max. height of image files for upload');
@define('MEDIA_UPLOAD_MAXHEIGHT_DESC', 'Enter the maximum image height in pixels for uploaded images.');
@define('MEDIA_UPLOAD_DIMERROR', 'Error: You cannot upload image files larger than %s x %s pixels!');

@define('MEDIA_TARGET', 'Target for this link');
@define('MEDIA_TARGET_JS', 'Popup window (via JavaScript, adaptive size)');
@define('MEDIA_ENTRY', 'Isolated Entry');
@define('MEDIA_TARGET_BLANK', 'Popup window (via target=_blank)');

@define('MEDIA_DYN_RESIZE', 'Allow dynamic image resizing?');
@define('MEDIA_DYN_RESIZE_DESC', 'If enabled, the media selector can return images in any requested size via a GET variable. The results are cached, and thus can create a large filebase if you make intensive use of it.');

@define('MEDIA_DIRECTORY_MOVED', 'Directory and files were successfully moved to %s');
@define('MEDIA_DIRECTORY_MOVE_ERROR', 'Directory and files could not be moved to %s!');
@define('MEDIA_DIRECTORY_MOVE_ENTRY', 'On Non-MySQL databases, iterating through every article to replace the old directory URLs with new directory URLs is not possible. You will need to manually edit your entries to fix new URLs. You can still move your old directory back to where it was, if that is too cumbersome for you.');
@define('MEDIA_DIRECTORY_MOVE_ENTRIES', 'Moved the URL of the moved directory in %s entries.');
@define('PLUGIN_ACTIVE', 'Active');
@define('PLUGIN_INACTIVE', 'Inactive');
@define('PREFERENCE_USE_JS', 'Enable advanced JS usage?');
@define('PREFERENCE_USE_JS_DESC', 'If enabled, advanced JavaScript sections will be enabled for better usability, like in the Plugin Configuration section you can use drag and drop for re-ordering plugins.');

@define('PREFERENCE_USE_JS_WARNING', '(This page uses advanced JavaScripting. If you are having functionality issues, please disable the use of advanced JS usage in your personal preferences or disable your browser\'s JavaScript)');


@define('INSTALL_PERMALINK_COMMENTSPATH', 'Path to comments');
@define('PERM_SET_CHILD', 'Set the same permissions on all child directories');
@define('PERMISSION_FORBIDDEN_PLUGINS', 'Forbidden plugins');
@define('PERMISSION_FORBIDDEN_HOOKS', 'Forbidden events');
@define('PERMISSION_FORBIDDEN_ENABLE', 'Enable Plugin ACL for usergroups?');
@define('PERMISSION_FORBIDDEN_ENABLE_DESC', 'If the option "Plugin ACL for usergroups" is enabled in the configuration, you can specify which usergroups are allowed to execute certain plugins/events.');
@define('DELETE_SELECTED_ENTRIES', 'Delete selected entries');
@define('PLUGIN_AUTHORS_MINCOUNT', 'Show only authors with at least X articles');
@define('FURTHER_LINKS_S9Y_BOOKMARKLET', 'Bookmarklet');
@define('FURTHER_LINKS_S9Y_BOOKMARKLET_DESC', 'Bookmark this link and then use it on any page you want to blog about to quickly access your Serendipity Blog.');
@define('IMPORT_WP_PAGES', 'Also fetch attachments and staticpages as normal blog entries?');
@define('USERCONF_CREATE', 'Disable user / forbid activity?');
@define('USERCONF_CREATE_DESC', 'If selected, the user will not have any editing or creation possibilities on the blog anymore. When logging in to the backend, he cannot do anything else apart from logging out and viewing his personal configuration.');
@define('CATEGORY_HIDE_SUB', 'Hide postings made to sub-categories?');
@define('CATEGORY_HIDE_SUB_DESC', 'By default, when you browse a category also entries of any subcategory are displayed. If this option is turned on, only postings of the currently selected category are displayed.');
@define('PINGBACK_SENDING', 'Sending pingback to URI %s...');
@define('PINGBACK_SENT', 'Pingback successful');
@define('PINGBACK_FAILED', 'Pingback failed: %s');
@define('PINGBACK_NOT_FOUND', 'No pingback-URI found.');
@define('CATEGORY_PLUGIN_HIDEZEROCOUNT', 'Hide archives link when no entries were made in that timespan (requires counting entries)');
@define('RSS_IMPORT_WPXRSS', 'WordPress eXtended RSS import, requires PHP5 and might take up much memory');
